summaryrefslogtreecommitdiffstats
path: root/kmail/headerstyle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/headerstyle.cpp')
-rw-r--r--kmail/headerstyle.cpp46
1 files changed, 23 insertions, 23 deletions
diff --git a/kmail/headerstyle.cpp b/kmail/headerstyle.cpp
index 3f3073ef7..0b728444f 100644
--- a/kmail/headerstyle.cpp
+++ b/kmail/headerstyle.cpp
@@ -19,11 +19,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -119,7 +119,7 @@ namespace KMail {
const HeaderStrategy * strategy,
const TQString & vCardName, bool printing, bool topLevel ) const {
Q_UNUSED( topLevel );
- if ( !message ) return TQString::null;
+ if ( !message ) return TQString();
if ( !strategy )
strategy = HeaderStrategy::brief();
@@ -218,7 +218,7 @@ namespace KMail {
const HeaderStrategy * strategy,
const TQString & vCardName, bool printing, bool topLevel ) const {
Q_UNUSED( topLevel );
- if ( !message ) return TQString::null;
+ if ( !message ) return TQString();
if ( !strategy )
strategy = HeaderStrategy::rich();
@@ -400,7 +400,7 @@ namespace KMail {
meterBar.fill( 22 );
else {
meterBar.fill( 21 );
- int max = QMIN( 20, static_cast<int>( percent ) / 5 );
+ int max = TQMIN( 20, static_cast<int>( percent ) / 5 );
for ( int i = 0; i < max; ++i ) {
meterBar.setColor( i+1, tqRgb( gradient[i][0], gradient[i][1],
gradient[i][2] ) );
@@ -419,7 +419,7 @@ namespace KMail {
const HeaderStrategy * strategy,
const TQString & vCardName, bool printing, bool topLevel ) const {
Q_UNUSED( topLevel );
- if ( !message ) return TQString::null;
+ if ( !message ) return TQString();
if ( !strategy )
strategy = HeaderStrategy::rich();
@@ -457,13 +457,13 @@ namespace KMail {
}
// Spam header display.
// If the spamSpamStatus config value is true then we look for headers
// from a few spam filters and try to create visually meaningful graphics
// out of the spam scores.
TQString spamHTML;
- if ( configReader.readBoolEntry( "showSpamStatus", true ) ) {
+ if ( configReader.readBoolEntry( "showSpamtqStatus", true ) ) {
SpamScores scores = SpamHeaderAnalyzer::getSpamScores( message );
for ( SpamScoresIterator it = scores.begin(); it != scores.end(); ++it )
spamHTML += (*it).agent() + " " +
@@ -478,7 +478,7 @@ namespace KMail {
::KIMProxy *imProxy = KMKernel::self()->imProxy();
TQString kabcUid;
KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
- KABC::AddresseeList addresses = addressBook->tqfindByEmail( KPIM::getFirstEmailAddress( message->from() ) );
+ KABC::AddresseeList addresses = addressBook->findByEmail( KPIM::getFirstEmailAddress( message->from() ) );
TQString photoURL;
int photoWidth = 60;
@@ -646,7 +646,7 @@ namespace KMail {
// kdDebug() << "FancyHeaderStyle::format() local zone offset (in minutes): " << lzone << endl;
- TQTime currTime = TQTime::currentTime( Qt::UTC );
+ TQTime currTime = TQTime::currentTime( TQt::UTC );
// kdDebug() << "FancyHeaderStyle::format() current time: " << currTime << endl;
@@ -662,7 +662,7 @@ namespace KMail {
color = "white";
bg_color = "#000B6B";
bg_image = "url(data:image/png;base64,"
- "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAIAAAASmSbdAAAAS0lEQVQI11WOsRGAQAzDOG/LHoz9"
+ "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAIAAAASmSbdAAAAS0lETQVQI11WOsRGATQAzDOG/LHoz9"
"kikIcF+kSBxbPs7LoNGVapAI0Zn+O+8NUwldozn6io7G7kdS/5zi7i+BvUM/5uSXlIfzMHx/bmWR"
"k++yj9rZAAAAAElFTkSuQmCC)";
}
@@ -671,8 +671,8 @@ namespace KMail {
color = "white";
bg_color = "#00A6FF";
bg_image = "url(data:image/png;base64,"
- "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAYAAACd+7GKAAAAWklEQVQI122OQQ7DMAzDaP3/dfuO"
- "pWSHJgva7iZIBk3m/Ew5hexCHVCilewzFHKEbFZqgxJQWyzKhWKl9unqddJj8+L9sl0oR2gUim+o"
+ "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAYAAACd+7GKAAAAWklETQVQI122OQQ7DMAzDaP3/dfuO"
+ "pWSHJgva7iZIBk3m/Ew5hexCHVCilewzFHKEbFZqgxJTQWyzKhWKl9unqddJj8+L9sl0oR2gUim+o"
"zu4uSh7kn67/DNv+C4tsZOtjAWEHAAAAAElFTkSuQmCC)";
}
else if ( currTime > TQTime( 12, 0, 0 ) && currTime <= TQTime( 18, 0, 0 ) ) {
@@ -680,8 +680,8 @@ namespace KMail {
color = "black";
bg_color = "#00A6FF";
bg_image = "url(data:image/png;base64,"
- "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAYAAACd+7GKAAAAPUlEQVQI132OwQ0AIAwCSfcfw91c"
- "QsCfRm399HFwoWjdDhMICQhxHSWMQPhkTCoqWRZU2h5i9tr4GZfmV5t3wWUI3h+NugAAAABJRU5E"
+ "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAYAAACd+7GKAAAAPUlETQVQI132OwQ0AIAwCSfcfw91c"
+ "QsCfRm399HFwoWjdDhMICQhxHSWMTQPhkTCoqWRZU2h5i9tr4GZfmV5t3wWUI3h+NugAAAABJRU5E"
"rkJggg==)";
}
else {
@@ -689,8 +689,8 @@ namespace KMail {
color = "white";
bg_color = "#0014CC";
bg_image = "url(data:image/png;base64,"
- "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAYAAACd+7GKAAAAWklEQVQI11WOyRHAMAgDNQuUlBrS"
- "fyFpAfKwje0PwyEt0vN+hVsJpzS6QML2ziWcFI6mZBZNSVDXYehyUgI1XsLI9eimHDH6kW0ddVIO"
+ "iVBORw0KGgoAAAANSUhEUgAAAAEAAAAyCAYAAACd+7GKAAAAWklETQVQI11WOyRHAMAgDNQuUlBrS"
+ "fyFpAfKwje0PwyEt0vN+hVsJpzS6TQML2ziWcFI6mZBZNSVDXYehyUgI1XsLI9eimHDH6kW0ddVIO"
"xx7JjrtshlbXlLDSD+WhJ+hwqWo8AAAAAElFTkSuQmCC)";
}
@@ -830,8 +830,8 @@ namespace KMail {
headerStr.append( TQString( "<tr><th>%1</th>\n"
"<td dir=\"%2\">%3</td></tr>\n")
.arg(i18n("Sender status: "))
- .arg( directionOf( onlineStatus ) )
- .arg(onlineStatus));
+ .arg( directionOf( onlinetqStatus ) )
+ .arg(onlinetqStatus));
*/
headerStr.append( TQString("<tr><td colspan=\"2\"><div id=\"attachmentInjectionPoint\"></div></td></tr>" ) );
headerStr.append(
@@ -841,7 +841,7 @@ namespace KMail {
if ( !spamHTML.isEmpty() )
headerStr.append( TQString( "<div class=\"spamheader\" dir=\"%1\"><b>%2</b>&nbsp;<span style=\"padding-left: 20px;\">%3</span></div>\n")
- .arg( subjectDir, i18n("Spam Status:"), spamHTML ) );
+ .arg( subjectDir, i18n("Spam tqStatus:"), spamHTML ) );
headerStr += "</div>\n\n";
return headerStr;
@@ -877,7 +877,7 @@ namespace KMail {
TQString EnterpriseHeaderStyle::format( const KMMessage * message,
const HeaderStrategy * strategy,
const TQString & vCardName, bool printing, bool topLevel ) const {
- if ( !message ) return TQString::null;
+ if ( !message ) return TQString();
if ( !strategy )
strategy = HeaderStrategy::brief();
@@ -899,7 +899,7 @@ namespace KMail {
subjectDir = directionOf( i18n("No Subject") );
// colors depend on if its encapsulated or not
- TQColor fontColor(Qt::white);
+ TQColor fontColor(TQt::white);
TQString linkColor = "class =\"white\"";
const TQColor activeColor = tqApp->palette().active().highlight();
TQColor activeColorDark = activeColor.dark(130);
@@ -457,13 +457,13 @@ namespace KMail {
}
// Spam header display.
- // If the spamSpamStatus config value is true then we look for headers
+ // If the spamSpamtqStatus config value is true then we look for headers
// from a few spam filters and try to create visually meaningful graphics
// out of the spam scores.